@@ -38,17 +38,18 @@ void create_main_window(struct w *widgets)
     GtkCellRenderer *pixbuf_cell_renderer;
     GdkPixbuf *pixbuf;
 
-    /* Create the main window */    
+    /* Create the main window */
     widgets->main_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     gtk_window_set_position(GTK_WINDOW (widgets->main_window), GTK_WIN_POS_CENTER);
-    gtk_widget_set_size_request(widgets->main_window, 720, 500);
+//    gtk_widget_set_size_request(widgets->main_window, 720, -1); //500);
+    gtk_widget_set_size_request(widgets->main_window, -1 , 500); //500);
 
     /* Set window information */
     info = g_strdup_printf("GADMIN-PROFTPD %s", VERSION);
     gtk_window_set_title(GTK_WINDOW(widgets->main_window), info);
     g_free(info);
 
-    /* Set the main window icon */    
+    /* Set the main window icon */
     pixmap_directory = g_strdup_printf("%s/pixmaps/gadmin-proftpd", PACKAGE_DATA_DIR);
     add_pixmap_directory(pixmap_directory);
     g_free(pixmap_directory);
