@@ -53,7 +53,7 @@ void restrict_pam_conf(int add_del)
     long file_size = 0;
     char *line, *new_conf;
     gchar *pam_module_off;
-    
+
     if((fp=fopen(PROFTPD_CONF, "r"))==NULL)
     {
 	/* We dont want to add anything unless the conf exists. */
@@ -170,13 +170,13 @@ void create_server_settings(struct w *widgets)
     tooltips = gtk_tooltips_new();
 
 
-    /* The servers hostname or IP-Address */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" The servers IP-address or hostname: "), 0,1,a,b,entry_size);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("ftp.mydomain.org, 192.168.0.100 or 0.0.0.0 which means listen to all network interfaces"), NULL);
+    /* The server address */
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Servers address: "), 0,1,a,b,entry_size);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("ftp.mydomain.org, 192.168.0.100 or 0.0.0.0 meaning listen to all network interfaces"), NULL);
     a++; b++; ent++;
 
     /* Alternative server ident Label+Entry+Combo */
-    widgets->server_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Alternative server identity: "), 0,1,a,b,entry_size);
+    widgets->server_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Server name: "), 0,1,a,b,entry_size);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("My FTP server or set it to off to have the server use its own name and version"), NULL);
 
     widgets->server_set_combo[comb] = make_combo(GTK_TABLE(widgets->srv_set_table), 1,2,a,b,combo_size);
@@ -190,7 +190,7 @@ void create_server_settings(struct w *widgets)
     a++; b++; ent++; comb++;
 
     /* Nat router Label+Entry+Combo */
-    widgets->server_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Configure NAT routing: "), 0,1,a,b,entry_size);
+    widgets->server_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" NAT router: "), 0,1,a,b,entry_size);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The public IP or DNS name of the NAT router, IE: router.mydomain.org or 192.168.0.100"), NULL);
 
     widgets->server_set_combo[comb] = make_combo(GTK_TABLE(widgets->srv_set_table), 1,2,a,b,combo_size);
@@ -204,12 +204,12 @@ void create_server_settings(struct w *widgets)
     a++; b++; ent++; comb++;
 
     /* Email */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" The administrators email address: "), 0,1,a,b,200);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Admin email: "), 0,1,a,b,200);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The administrators email address"), NULL);
     a++; b++; ent++;
 
     /* Identity lookups */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Use identity lookups: "), 0,1,a,b,50);
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Identity lookups: "), 0,1,a,b,50);
     combo_text = g_strdup_printf(_("On"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -220,7 +220,7 @@ void create_server_settings(struct w *widgets)
     a++; b++; comb++;
 
     /* Reverse lookups */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Use reverse lookups: "), 0,1,a,b,50);
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Reverse lookups: "), 0,1,a,b,50);
     combo_text = g_strdup_printf(_("On"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -256,12 +256,12 @@ void create_server_settings(struct w *widgets)
     a++; b++; spin++;
 
     /* Max connections */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Maximum connections: "), 0,1,a,b,50);
+    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Max connections: "), 0,1,a,b,50);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("The maximum simoultaneous connections for this server"), NULL);
     a++; b++; spin++;
 
     /* Maximum logins */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Maximum login tries: "), 0,1,a,b,50);
+    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Max login tries: "), 0,1,a,b,50);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("The maximum number of logins a user can fail before disconnected"), NULL);
     a++; b++; spin++;
 
@@ -337,9 +337,9 @@ void create_server_settings(struct w *widgets)
 		                		 			    G_CALLBACK(virtual_users_toggled), widgets);
 
 
-    /* Default statistics file */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Default HTML statistics filepath: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("This will be set as the default HTML statistics filepath, IE: /var/www/ftp.htm"), NULL);
+    /* Statistics file */
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" HTML statistics file: "), 0,1,a,b,200);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Generated HTML statistics file, IE: /var/www/ftp.htm"), NULL);
     a++; b++; ent++;
 
 
@@ -421,8 +421,8 @@ void create_server_settings(struct w *widgets)
     g_free(combo_text); g_free(utf8);
     a++; b++; comb++;
 
-    /* Automatically remove aborted uploads */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Automatically remove aborted uploads: "), 0,1,a,b,50);
+    /* Remove aborted uploads */
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Remove aborted uploads: "), 0,1,a,b,50);
     combo_text = g_strdup_printf(_("On"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -440,12 +440,12 @@ void create_server_settings(struct w *widgets)
 	make_3columns_hseparator(GTK_TABLE(widgets->srv_set_table), 0,1,a,b);
 	a++; b++;
 	
-	/* FTP-TLS label */
-	make_3columns_label(GTK_TABLE(widgets->srv_set_table), _(" FTP-TLS secure communications: "), 0,1,a,b);
+	/* Secure communications label */
+	make_3columns_label(GTK_TABLE(widgets->srv_set_table), _(" Secure communications: "), 0,1,a,b);
 	a++; b++;
 
-	/* Use FTP-TLS secure communication */
-	widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Use FTP-TLS secure communications: "), 0,1,a,b,50);
+	/* Use secure communication */
+	widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Use secure communication: "), 0,1,a,b,50);
 	combo_text = g_strdup_printf(_("On"));
 	utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
 	gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -508,7 +508,7 @@ void create_server_settings(struct w *widgets)
 
 
 	/* This servers DNS name or IP-Address */
-	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" This servers DNS name or IP-Address: "), 0,1,a,b,200);
+	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Server address: "), 0,1,a,b,200);
 	gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("This servers DNS name or IP address"), NULL);
 	a++; b++; ent++;
 
@@ -545,24 +545,24 @@ void create_server_settings(struct w *widgets)
 	/* Was challenge password, let it be for now */
 	a++; b++; ent++;
 
-	/* Number of encryption bits (Min value = 384) */
-	widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Number of encryption bits: "), 0,1,a,b,50);
+	/* Encryption bits (Min value = 384) */
+	widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Encryption bits: "), 0,1,a,b,50);
 	gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Number of bits in the generated certificate"), NULL);
 	gtk_spin_button_set_range(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[spin]), 384, 999999);
 	a++; b++; spin++;
 
 	/* Number of days the certificate is valid */
-	widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Number of days the certificate is valid: "), 0,1,a,b,50);
+	widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Days valid: "), 0,1,a,b,50);
 	gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Number of days the certificate is valid"), NULL);
 	a++; b++; spin++;
 
 	/* Countrycode */
-	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Country code IE: SV, DK, EN, US: "), 0,1,a,b,200);
+	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Country code IE: SV, DK, DE, EN, US: "), 0,1,a,b,200);
 	gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The country code"), NULL);
 	a++; b++; ent++;
 
 	/* A progress bar */
-	widgets->gen_cert_progressbar = make_progressbar_with_label(GTK_TABLE(widgets->srv_set_table), _(" Generate new certificate: "), 0,1,a,b,210);
+	widgets->gen_cert_progressbar = make_progressbar_with_label(GTK_TABLE(widgets->srv_set_table), _(" Generate new certificates: "), 0,1,a,b,210);
 	gtk_widget_set_sensitive(widgets->gen_cert_progressbar, FALSE);
 
 	/* The progress bar looks nicer if its blue from start */
