@@ -55,13 +55,13 @@ void create_server_tab(struct w *widgets)
 
     GtkTooltips *tooltips;
     tooltips = gtk_tooltips_new();
-    
+
 
     /* Create the domain treeview in a scrolled window */
     server_treeview_hbox = gtk_hbox_new(TRUE, 0);
     gtk_box_pack_start(GTK_BOX(widgets->notebook_vbox1), server_treeview_hbox, EXPAND_SERVER_SECTION, TRUE, 0);
 
-    server_scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+    server_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
     gtk_box_pack_start(GTK_BOX(server_treeview_hbox), server_scrolled_window, TRUE, TRUE, 0);
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(server_scrolled_window), 
 						    GTK_POLICY_AUTOMATIC, 
@@ -69,7 +69,7 @@ void create_server_tab(struct w *widgets)
     /* Must set a larger size or it wont scroll */
     gtk_widget_set_size_request(server_scrolled_window, -1, 100);
 
-    widgets->server_store = gtk_list_store_new (4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
+    widgets->server_store = gtk_list_store_new(4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 
     widgets->server_treeview = gtk_tree_view_new();
     gtk_tree_view_set_model(GTK_TREE_VIEW(widgets->server_treeview), GTK_TREE_MODEL(widgets->server_store));
@@ -154,8 +154,8 @@ void create_server_tab(struct w *widgets)
     widgets->server_settings_scrolled_window = gtk_scrolled_window_new (NULL, NULL);
     gtk_box_pack_start(GTK_BOX(settings_treeview_hbox), widgets->server_settings_scrolled_window, TRUE, TRUE, 0);
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(widgets->server_settings_scrolled_window), 
-						    GTK_POLICY_AUTOMATIC, 
-						    GTK_POLICY_ALWAYS);
+						    GTK_POLICY_NEVER,
+						    GTK_POLICY_AUTOMATIC);
 
     /* Must set a larger size or it wont scroll */
     gtk_widget_set_size_request(widgets->server_settings_scrolled_window, -1, 100);
